@@ -1,30 +1,28 @@
 from __future__ import absolute_import
 
 import yaml
-
 from prospector.formatters.base import Formatter
 
-
-__all__ = (
-    'YamlFormatter',
-)
+__all__ = ("YamlFormatter",)
 
 
-# pylint: disable=R0903
+# pylint: disable=too-few-public-methods
 class YamlFormatter(Formatter):
-    def render(self, summary=True, messages=True):
+    def render(self, summary=True, messages=True, profile=False):
         output = {}
 
         if summary:
-            output['summary'] = self.summary
+            output["summary"] = self.summary
+
+        if profile:
+            output["profile"] = self.profile.as_dict()
 
         if messages:
-            output['messages'] = [m.as_dict() for m in self.messages]
+            output["messages"] = [m.as_dict() for m in self.messages]
 
         return yaml.safe_dump(
             output,
             indent=2,
             default_flow_style=False,
-            encoding='utf-8',
             allow_unicode=True,
         )
